==> junit-contracts-0.1.2-sources.jar: org/xenei/junit/contract/tooling/InterfaceInfo.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.xenei.junit.contract.tooling;

import java.util.HashSet;
import java.util.Set;

/**
 * The information about an interface.
 *
 * tracks the interface class and the classes that test the interface.
 *
 */
public class InterfaceInfo {
	// the interface class
	private final Class<?> name;
	// the tests that apply to the interface
	private final Set<Class<?>> tests;

	/**
	 * Constructor
	 */
	public InterfaceInfo(final Class<?> name) {
		this.name = name;
		this.tests = new HashSet<Class<?>>();
	}

	/**
	 * Add a test to the list of tests that apply to the interface.
	 * 
	 * @param test
	 *            The test to add.
	 */
	public void add(final Class<?> test) {
		tests.add(test);
	}

	/**
	 * Get the set of tests for the interface.
	 * 
	 * @return
	 */
	public Set<Class<?>> getTests() {
		return tests;
	}

	/**
	 * Get the interface class
	 * 
	 * @return The interface class.
	 */
	public Class<?> getName() {
		return name;
	}
}

==> junit-contracts-0.1.7-sources.jar: org/xenei/junit/contract/tooling/InterfaceInfo.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.xenei.junit.contract.tooling;

import java.util.HashSet;
import java.util.Set;

/**
 * The information about an interface.
 *
 * tracks the interface class and the classes that test the interface.
 *
 */
public class InterfaceInfo {
	// the interface class
	private final Class<?> name;
	// the tests that apply to the interface
	private final Set<Class<?>> tests;

	/**
	 * Constructor
	 * 
	 * @param name
	 *            The interface class.
	 */
	public InterfaceInfo(final Class<?> name) {
		this.name = name;
		this.tests = new HashSet<Class<?>>();
	}

	/**
	 * Add a test to the list of tests that apply to the interface.
	 * 
	 * @param test
	 *            The test to add.
	 */
	public void add(final Class<?> test) {
		tests.add(test);
	}

	/**
	 * Get the set of tests for the interface.
	 * 
	 * @return the set of Class object representing the tests.
	 */
	public Set<Class<?>> getTests() {
		return tests;
	}

	/**
	 * Get the interface class
	 * 
	 * @return The interface class.
	 */
	public Class<?> getName() {
		return name;
	}
}
